@@ -28,7 +28,7 @@
       INTEGER MPIO_REQUEST_NULL
       PARAMETER (MPIO_REQUEST_NULL=0)
 !
-      integer*8 MPI_DISPLACEMENT_CURRENT
+      integer MPI_DISPLACEMENT_CURRENT
       PARAMETER (MPI_DISPLACEMENT_CURRENT=-54278278)
 !
 !
